SymbolEventRecord

Struct SymbolEventRecord 

pub struct SymbolEventRecord {
    pub symbol_id: SymbolId,
    pub name: String,
    pub symbol_kind: SymbolKind,
    pub at: ClockTime,
}
Symbol-table event record. Shared shape across SYMBOL_* opcodes.

Fields

symbol_id: SymbolId

Symbol ID being affected.

name: String

Canonical or alias name attached by this event (may be empty for retire/unretire where the spec says the field is ignored).

symbol_kind: SymbolKind

Locked kind for this symbol.

at: ClockTime

Timestamp of the event.