Value — the typed-value enum used in memory slots that accept either
a symbol, a number, a boolean, a string, or a timestamp. Matches the
value-tag set in docs/concepts/ir-canonical-form.md  3.2.
Enums
- Value
- A typed value that can appear in a memory slot such as
crate::Semantic::oorcrate::Procedural::trigger.